
/***********************************************************************/
/* nsock_read.c -- This contains the functions for requesting timers   */
/* from the nsock parallel socket event library                        */
/*                                                                     */
/***********************************************************************/
/*  The nsock parallel socket event library is (C) 2000 Insecure.Com   */
/*  LLC This library is free software; you can redistribute it and/or  */
/*  modify it under the terms of the GNU General Public License as     */
/*  published by the Free Software Foundation; Version 2.  This        */
/*  guarantees your right to use, modify, and redistribute this        */
/*  software under certain conditions.  If this license is             */
/*  unacceptable to you, Insecure.Com LLC may be willing to sell       */
/* alternative licenses (contact fyodor@insecure.org ).                */
/*                                                                     */
/*  If you received these files with a written license agreement       */
/*  stating terms other than the (GPL) terms above, then that          */
/*  alternative license agreement takes precendence over this comment. */
/*                                                                     */
/*  Source is provided to this software because we believe users have  */
/*  a right to know exactly what a program is going to do before they  */
/*  run it.  This also allows you to audit the software for security   */
/*  holes (none have been found so far).                               */
/*                                                                     */
/*  Source code also allows you to port nsock to new platforms, fix    */
/*  bugs, and add new features.  You are highly encouraged to send     */
/*  your changes to Fyodor for possible incorporation into the main    */
/*  distribution.  By sending these changes to Fyodor or one the       */
/*  insecure.org development mailing lists, it is assumed that you     */
/*  are offering Fyodor the unlimited, non-exclusive right to reuse,   */
/*  modify, and relicense the code.  If you wish to specify special    */
/*  license conditions of your contributions, please state them up     */
/*  front.                                                             */
/*                                                                     */
/*  This program is distributed in the hope that it will be useful,    */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of     */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU  */
/*  General Public License for more details (                          */
/*  http://www.gnu.org/copyleft/gpl.html ).                            */
/*                                                                     */
/***********************************************************************/

/* $Id: nsock_timers.c,v 1.4 2003/07/16 23:50:39 fyodor Exp $ */

#include "nsock_internal.h"

/* Send back an NSE_TYPE_TIMER after the number of milliseconds specified.  Of course it can also return due to error, cancellation, etc. */
nsock_event_id nsock_timer_create(nsock_pool ms_pool, nsock_ev_handler handler, 
			    int timeout_msecs, void *userdata) {
  mspool *nsp = (mspool *) ms_pool;
  msevent *nse;

  nse = msevent_new(nsp, NSE_TYPE_TIMER, NULL, timeout_msecs, handler,
		    userdata);
  assert(nse);

  if (nsp->tracelevel > 0) {
    nsock_trace(nsp, "Timer created - %dms from now.  EID %li", timeout_msecs, nse->id);
  }

  nsp_add_event(nsp, nse);
  
  return nse->id;
}

